Documentation
¶
Index ¶
- func GenMan(cmd boot.Commander, header *GenManHeader, w io.Writer) error
- func GenManTree(cmd boot.Commander, header *GenManHeader, dir string) error
- func GenManTreeFromOpts(cmd boot.Commander, opts GenManTreeOptions) error
- func GenMarkdown(cmd boot.Commander, w io.Writer) error
- func GenMarkdownCustom(cmd boot.Commander, w io.Writer, linkHandler func(string) string) error
- func GenMarkdownTree(cmd boot.Commander, dir string) error
- func GenMarkdownTreeCustom(cmd boot.Commander, dir string, filePrepender, linkHandler func(string) string) error
- func GenReST(cmd boot.Commander, w io.Writer) error
- func GenReSTCustom(cmd boot.Commander, w io.Writer, linkHandler func(string, string) string) error
- func GenReSTTree(cmd boot.Commander, dir string) error
- func GenReSTTreeCustom(cmd boot.Commander, dir string, filePrepender func(string) string, ...) error
- func GenYaml(cmd boot.Commander, w io.Writer) error
- func GenYamlCustom(cmd boot.Commander, w io.Writer, linkHandler func(string) string) error
- func GenYamlTree(cmd boot.Commander, dir string) error
- func GenYamlTreeCustom(cmd boot.Commander, dir string, filePrepender, linkHandler func(string) string) error
- type GenManHeader
- type GenManTreeOptions
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenMan ¶
GenMan will generate a man page for the given command and write it to w. The header argument may be nil, however obviously w may not.
Example ¶
package main
import (
"bytes"
"fmt"
"github.com/nbcx/boot"
"github.com/nbcx/boot/doc"
)
func main() {
cmd := &boot.Command{
Use: "test",
Short: "my test program",
}
header := &doc.GenManHeader{
Title: "MINE",
Section: "3",
}
out := new(bytes.Buffer)
boot.CheckErr(doc.GenMan(cmd, header, out))
fmt.Print(out.String())
}
Output:
func GenManTree ¶
func GenManTree(cmd boot.Commander, header *GenManHeader, dir string) error
GenManTree will generate a man page for this command and all descendants in the directory given. The header may be nil. This function may not work correctly if your command names have `-` in them. If you have `cmd` with two subcmds, `sub` and `sub-third`, and `sub` has a subcommand called `third` it is undefined which help output will be in the file `cmd-sub-third.1`.
Example ¶
package main
import (
"github.com/nbcx/boot"
"github.com/nbcx/boot/doc"
)
func main() {
cmd := &boot.Command{
Use: "test",
Short: "my test program",
}
header := &doc.GenManHeader{
Title: "MINE",
Section: "3",
}
boot.CheckErr(doc.GenManTree(cmd, header, "/tmp"))
}
Output:
func GenManTreeFromOpts ¶
func GenManTreeFromOpts(cmd boot.Commander, opts GenManTreeOptions) error
GenManTreeFromOpts generates a man page for the command and all descendants. The pages are written to the opts.Path directory.
func GenMarkdown ¶
GenMarkdown creates markdown output.
func GenMarkdownCustom ¶
GenMarkdownCustom creates custom markdown output.
func GenMarkdownTree ¶
GenMarkdownTree will generate a markdown page for this command and all descendants in the directory given. The header may be nil. This function may not work correctly if your command names have `-` in them. If you have `cmd` with two subcmds, `sub` and `sub-third`, and `sub` has a subcommand called `third`, it is undefined which help output will be in the file `cmd-sub-third.1`.
func GenMarkdownTreeCustom ¶
func GenMarkdownTreeCustom(cmd boot.Commander, dir string, filePrepender, linkHandler func(string) string) error
GenMarkdownTreeCustom is the same as GenMarkdownTree, but with custom filePrepender and linkHandler.
func GenReSTCustom ¶
GenReSTCustom creates custom reStructured Text output.
func GenReSTTree ¶
GenReSTTree will generate a ReST page for this command and all descendants in the directory given. This function may not work correctly if your command names have `-` in them. If you have `cmd` with two subcmds, `sub` and `sub-third`, and `sub` has a subcommand called `third`, it is undefined which help output will be in the file `cmd-sub-third.1`.
func GenReSTTreeCustom ¶
func GenReSTTreeCustom(cmd boot.Commander, dir string, filePrepender func(string) string, linkHandler func(string, string) string) error
GenReSTTreeCustom is the same as GenReSTTree, but with custom filePrepender and linkHandler.
func GenYamlCustom ¶
GenYamlCustom creates custom yaml output.
func GenYamlTree ¶
GenYamlTree creates yaml structured ref files for this command and all descendants in the directory given. This function may not work correctly if your command names have `-` in them. If you have `cmd` with two subcmds, `sub` and `sub-third`, and `sub` has a subcommand called `third` it is undefined which help output will be in the file `cmd-sub-third.1`.
Types ¶
type GenManHeader ¶
type GenManHeader struct {
Title string
Section string
Date *time.Time
Source string
Manual string
// contains filtered or unexported fields
}
GenManHeader is a lot like the .TH header at the start of man pages. These include the title, section, date, source, and manual. We will use the current time if Date is unset and will use "Auto generated by spf13/cobra" if the Source is unset.
type GenManTreeOptions ¶
type GenManTreeOptions struct {
Header *GenManHeader
Path string
CommandSeparator string
}
GenManTreeOptions is the options for generating the man pages. Used only in GenManTreeFromOpts.